package com.younike.system.mapper;

import com.younike.system.domain.ServerTimeSection;

import java.util.List;

/**
 * 服务人员服务时间段Mapper接口
 *
 * @author jubs
 * @date 2022-01-13
 */
public interface MerchantServerTimeSectionMapper {
    /**
     * 查询服务人员服务时间段
     *
     * @param sectionId 服务人员服务时间段主键
     * @return 服务人员服务时间段
     */
    ServerTimeSection selectServerTimeSectionBySectionId(String sectionId);

    /**
     * 查询服务人员服务时间段列表
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 服务人员服务时间段集合
     */
    List<ServerTimeSection> selectServerTimeSectionList(ServerTimeSection serverTimeSection);

    /**
     * 新增服务人员服务时间段
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 结果
     */
    int insertServerTimeSection(ServerTimeSection serverTimeSection);

    /**
     * 修改服务人员服务时间段
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 结果
     */
    int updateServerTimeSection(ServerTimeSection serverTimeSection);

    /**
     * 删除服务人员服务时间段
     *
     * @param sectionId 服务人员服务时间段主键
     * @return 结果
     */
    int deleteServerTimeSectionBySectionId(String sectionId);

    /**
     * 批量删除服务人员服务时间段
     *
     * @param sectionIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteServerTimeSectionBySectionIds(String[] sectionIds);
}
